'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = Box;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function getOpacity(value) {
  if (typeof value === 'number') {
    if (value > 1) {
      return 1;
    }

    if (value < 0) {
      return 0;
    }

    return value;
  }

  return 1;
}

function getBorderWidth(type, width) {
  if (!type) {
    return width;
  }

  var top = 0;
  var right = 0;
  var bottom = 0;
  var left = 0;

  if (type === 'horizontal' || type === 'top') {
    top = width;
  }

  if (type === 'horizontal' || type === 'bottom') {
    bottom = width;
  }

  if (type === 'vertical' || type === 'left') {
    left = width;
  }

  if (type === 'vertical' || type === 'right') {
    right = width;
  }

  return [top, right, bottom, left, ''].join('px ');
}

/**
 * Box component
 */
function Box(props) {
  var tagType = props.tagType,
      fill = props.fill,
      fillOpacity = props.fillOpacity,
      stroke = props.stroke,
      strokeWidth = props.strokeWidth,
      borderRadius = props.borderRadius,
      strokeOpacity = props.strokeOpacity,
      strokeStyle = props.strokeStyle,
      strokeType = props.strokeType,
      style = props.style,
      other = _objectWithoutProperties(props, ['tagType', 'fill', 'fillOpacity', 'stroke', 'strokeWidth', 'borderRadius', 'strokeOpacity', 'strokeStyle', 'strokeType', 'style']);

  var newStyle = _extends({}, style, {
    backgroundColor: fill ? 'rgba(var(--' + fill + '), ' + getOpacity(fillOpacity) + ')' : undefined,
    borderColor: stroke ? 'rgba(var(--' + stroke + '), ' + getOpacity(strokeOpacity) + ')' : undefined,
    borderWidth: stroke ? getBorderWidth(strokeType, strokeWidth) : undefined,
    borderStyle: stroke ? strokeStyle : undefined,
    borderRadius: typeof borderRadius === 'number' ? borderRadius + 'px' : undefined
  });

  var Component = tagType;

  return _react2.default.createElement(Component, _extends({}, other, {
    style: newStyle
  }));
}

Box.propTypes = {
  /**
   * This is what will be displayed inside the component.
   */
  children: _propTypes2.default.node,
  /**
   * The component used for the root node.
   * Either a string to use a DOM element.
   */
  tagType: _propTypes2.default.string,
  /**
   * Component background-color from theme.
   */
  fill: _propTypes2.default.string,
  /**
   * Component background-color opacity.
   */
  fillOpacity: _propTypes2.default.number,
  /**
   * Component border-color from theme.
   */
  stroke: _propTypes2.default.string,
  /**
   * Component border width.
   */
  strokeWidth: _propTypes2.default.number,
  /**
   * Component border-radius in pixels.
   */
  borderRadius: _propTypes2.default.number,
  /**
   * Component border-color opacity.
   */
  strokeOpacity: _propTypes2.default.number,
  /**
   * Component border style.
   */
  strokeStyle: _propTypes2.default.oneOf(['solid', 'dashed', 'dotted', 'none']),
  /**
   * Component border position.
   */
  strokeType: _propTypes2.default.oneOf(['horizontal', 'vertical', 'top', 'right', 'bottom', 'left']),
  /**
   * The CSS class name of the root element.
   */
  className: _propTypes2.default.string
};

Box.defaultProps = {
  children: null,
  tagType: 'div',
  fill: undefined,
  fillOpacity: undefined,
  stroke: undefined,
  strokeStyle: 'solid',
  strokeWidth: 1,
  borderRadius: undefined,
  strokeOpacity: undefined,
  strokeType: undefined,
  className: undefined
};
//# sourceMappingURL=index.js.map