var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

/**
 * SelectItem component
 */
export default function SelectItem(props) {
  var children = props.children,
      value = props.value,
      selected = props.selected,
      disabled = props.disabled,
      focused = props.focused,
      className = props.className,
      textColor = props.textColor,
      size = props.size,
      other = _objectWithoutProperties(props, ['children', 'value', 'selected', 'disabled', 'focused', 'className', 'textColor', 'size']);

  return React.createElement(
    'li',
    _extends({
      'data-component': 'select_item',
      'aria-disabled': disabled,
      'aria-selected': selected,
      'data-focused': focused,
      'data-value': value,
      className: classNames('select_item', 'truncate_text', ['select_item_' + size], ['text_' + textColor], className),
      role: 'option',
      tabIndex: -1
    }, other),
    children
  );
}

SelectItem.propTypes = {
  children: PropTypes.oneOfType([PropTypes.number, PropTypes.string, PropTypes.node]).isRequired,
  value: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isRequired,
  selected: PropTypes.bool,
  disabled: PropTypes.bool,
  focused: PropTypes.bool,
  className: PropTypes.string,
  /**
   * Component text color from theme
   */
  textColor: PropTypes.string,
  /**
   * Component size
   */
  size: PropTypes.oneOf(['medium', 'large'])
};

SelectItem.defaultProps = {
  selected: false,
  disabled: false,
  focused: false,
  className: '',
  textColor: 'black',
  size: 'medium'
};
//# sourceMappingURL=select_item.js.map